import { jsx as _jsx } from "react/jsx-runtime";
import { useState, useEffect, useRef } from 'react';
import PropTypes from 'prop-types';
import { createPortal } from 'react-dom';
import cx from 'classnames';
import { useEventListener, useBoolean } from '@s-ui/react-hooks';
var Overlay = 'div';
var Body = 'div';
var Content = 'div';
var PLACEMENTS = {
  TOP: 'top',
  RIGHT: 'right',
  BOTTOM: 'bottom',
  LEFT: 'left'
};
export default function MoleculeDrawer(_ref) {
  var _ref$portalContainerI = _ref.portalContainerId,
      portalContainerId = _ref$portalContainerI === void 0 ? 'drawer-react-portal' : _ref$portalContainerI,
      _ref$isOpen = _ref.isOpen,
      isOpen = _ref$isOpen === void 0 ? false : _ref$isOpen,
      _ref$placement = _ref.placement,
      placement = _ref$placement === void 0 ? PLACEMENTS.LEFT : _ref$placement,
      onClose = _ref.onClose,
      children = _ref.children;
  var overlayRef = useRef(null);

  var _useState = useState(false),
      isClientReady = _useState[0],
      setClientReady = _useState[1];

  var _useBoolean = useBoolean(isOpen),
      value = _useBoolean[0],
      _useBoolean$ = _useBoolean[1],
      off = _useBoolean$.off,
      on = _useBoolean$.on;

  useEffect(function () {
    setClientReady(true);
  }, []);
  useEffect(function () {
    isOpen && on();
  }, [isOpen, on]);
  useEventListener('keydown', function (ev) {
    if (isOpen === false) return;

    if (ev.key === 'Escape') {
      onClose(ev);
      ev.preventDefault();
    }
  });

  var getContainer = function getContainer() {
    var containerDOMEl = document.getElementById(portalContainerId);

    if (!containerDOMEl) {
      containerDOMEl = document.createElement('div');
      containerDOMEl.id = portalContainerId;
      document.body.appendChild(containerDOMEl);
    }

    return containerDOMEl;
  };

  var drawer = value && /*#__PURE__*/_jsx("div", {
    className: "react-MoleculeDrawer",
    children: /*#__PURE__*/_jsx(Overlay, {
      ref: overlayRef,
      className: "react-MoleculeDrawer-overlay",
      onClick: function onClick(e) {
        overlayRef.current === e.target && onClose();
      },
      children: /*#__PURE__*/_jsx(Content, {
        onAnimationEnd: function onAnimationEnd() {
          return !isOpen && off();
        },
        className: cx('react-MoleculeDrawer-content', "react-MoleculeDrawer-content--" + placement),
        style: {
          animation: (isOpen ? 'open' : 'close') + "-drawer-" + placement + " 0.3s both"
        },
        children: /*#__PURE__*/_jsx(Body, {
          className: "react-MoleculeDrawer-body",
          children: children
        })
      })
    })
  });

  return isClientReady ? /*#__PURE__*/createPortal(drawer, getContainer()) : null;
}
export { PLACEMENTS as moleculeDrawerPlacements };
MoleculeDrawer.displayName = 'MoleculeDrawer';
MoleculeDrawer.propTypes = {
  /** Tells if the drawer is open or not */
  isOpen: PropTypes.bool,

  /** On close callback used to manage the isOpen prop from the parent */
  onClose: PropTypes.func.isRequired,

  /** Screen position where the drawer will be displayed */
  placement: PropTypes.oneOf(Object.values(PLACEMENTS))
};